# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryGoogleDriveFolders(BaseModel):
    google_drive_folders: Optional["QueryGoogleDriveFoldersGoogleDriveFolders"] = Field(
        alias="googleDriveFolders"
    )


class QueryGoogleDriveFoldersGoogleDriveFolders(BaseModel):
    results: Optional[
        List[Optional["QueryGoogleDriveFoldersGoogleDriveFoldersResults"]]
    ]


class QueryGoogleDriveFoldersGoogleDriveFoldersResults(BaseModel):
    folder_name: Optional[str] = Field(alias="folderName")
    folder_id: Optional[str] = Field(alias="folderId")


QueryGoogleDriveFolders.model_rebuild()
QueryGoogleDriveFoldersGoogleDriveFolders.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    ContentFacetTypes,
    ContentTypes,
    ConversationRoleTypes,
    EntityState,
    EntityTypes,
    FacetValueTypes,
    FileTypes,
    ImageProjectionTypes,
    ModelServiceTypes,
    ObservableTypes,
    OrientationTypes,
)


class ContinueConversation(BaseModel):
    continue_conversation: Optional["ContinueConversationContinueConversation"] = Field(
        alias="continueConversation"
    )


class ContinueConversationContinueConversation(BaseModel):
    conversation: Optional["ContinueConversationContinueConversationConversation"]
    message: Optional["ContinueConversationContinueConversationMessage"]
    message_count: Optional[int] = Field(alias="messageCount")
    facets: Optional[List[Optional["ContinueConversationContinueConversationFacets"]]]
    graph: Optional["ContinueConversationContinueConversationGraph"]
    details: Optional["ContinueConversationContinueConversationDetails"]


class ContinueConversationContinueConversationConversation(BaseModel):
    id: str


class ContinueConversationContinueConversationMessage(BaseModel):
    role: ConversationRoleTypes
    author: Optional[str]
    message: Optional[str]
    citations: Optional[
        List[Optional["ContinueConversationContinueConversationMessageCitations"]]
    ]
    tool_calls: Optional[
        List[Optional["ContinueConversationContinueConversationMessageToolCalls"]]
    ] = Field(alias="toolCalls")
    tokens: Optional[int]
    throughput: Optional[float]
    ttft: Optional[Any]
    completion_time: Optional[Any] = Field(alias="completionTime")
    timestamp: Optional[Any]
    model_service: Optional[ModelServiceTypes] = Field(alias="modelService")
    model: Optional[str]
    data: Optional[str]
    mime_type: Optional[str] = Field(alias="mimeType")
    tool_call_id: Optional[str] = Field(alias="toolCallId")
    tool_call_response: Optional[str] = Field(alias="toolCallResponse")


class ContinueConversationContinueConversationMessageCitations(BaseModel):
    content: Optional["ContinueConversationContinueConversationMessageCitationsContent"]
    index: Optional[int]
    text: str
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_number: Optional[int] = Field(alias="pageNumber")
    frame_number: Optional[int] = Field(alias="frameNumber")


class ContinueConversationContinueConversationMessageCitationsContent(BaseModel):
    id: str
    name: str
    state: EntityState
    original_date: Optional[Any] = Field(alias="originalDate")
    identifier: Optional[str]
    uri: Optional[Any]
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    format: Optional[str]
    format_name: Optional[str] = Field(alias="formatName")
    file_extension: Optional[str] = Field(alias="fileExtension")
    file_name: Optional[str] = Field(alias="fileName")
    file_size: Optional[Any] = Field(alias="fileSize")
    master_uri: Optional[Any] = Field(alias="masterUri")
    image_uri: Optional[Any] = Field(alias="imageUri")
    text_uri: Optional[Any] = Field(alias="textUri")
    audio_uri: Optional[Any] = Field(alias="audioUri")
    transcript_uri: Optional[Any] = Field(alias="transcriptUri")
    summary: Optional[str]
    custom_summary: Optional[str] = Field(alias="customSummary")
    keywords: Optional[List[str]]
    bullets: Optional[List[str]]
    headlines: Optional[List[str]]
    posts: Optional[List[str]]
    chapters: Optional[List[str]]
    questions: Optional[List[str]]
    quotes: Optional[List[str]]
    video: Optional[
        "ContinueConversationContinueConversationMessageCitationsContentVideo"
    ]
    audio: Optional[
        "ContinueConversationContinueConversationMessageCitationsContentAudio"
    ]
    image: Optional[
        "ContinueConversationContinueConversationMessageCitationsContentImage"
    ]
    document: Optional[
        "ContinueConversationContinueConversationMessageCitationsContentDocument"
    ]


class ContinueConversationContinueConversationMessageCitationsContentVideo(BaseModel):
    width: Optional[int]
    height: Optional[int]
    duration: Optional[Any]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    title: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]


class ContinueConversationContinueConversationMessageCitationsContentAudio(BaseModel):
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]
    series: Optional[str]
    episode: Optional[str]
    episode_type: Optional[str] = Field(alias="episodeType")
    season: Optional[str]
    publisher: Optional[str]
    copyright: Optional[str]
    genre: Optional[str]
    title: Optional[str]
    description: Optional[str]
    bitrate: Optional[int]
    channels: Optional[int]
    sample_rate: Optional[int] = Field(alias="sampleRate")
    bits_per_sample: Optional[int] = Field(alias="bitsPerSample")
    duration: Optional[Any]


class ContinueConversationContinueConversationMessageCitationsContentImage(BaseModel):
    width: Optional[int]
    height: Optional[int]
    resolution_x: Optional[int] = Field(alias="resolutionX")
    resolution_y: Optional[int] = Field(alias="resolutionY")
    bits_per_component: Optional[int] = Field(alias="bitsPerComponent")
    components: Optional[int]
    projection_type: Optional[ImageProjectionTypes] = Field(alias="projectionType")
    orientation: Optional[OrientationTypes]
    description: Optional[str]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    lens: Optional[str]
    focal_length: Optional[float] = Field(alias="focalLength")
    exposure_time: Optional[str] = Field(alias="exposureTime")
    f_number: Optional[str] = Field(alias="fNumber")
    iso: Optional[str]
    heading: Optional[float]
    pitch: Optional[float]


class ContinueConversationContinueConversationMessageCitationsContentDocument(
    BaseModel
):
    title: Optional[str]
    subject: Optional[str]
    summary: Optional[str]
    author: Optional[str]
    publisher: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    page_count: Optional[int] = Field(alias="pageCount")
    worksheet_count: Optional[int] = Field(alias="worksheetCount")
    slide_count: Optional[int] = Field(alias="slideCount")
    word_count: Optional[int] = Field(alias="wordCount")
    line_count: Optional[int] = Field(alias="lineCount")
    paragraph_count: Optional[int] = Field(alias="paragraphCount")
    is_encrypted: Optional[bool] = Field(alias="isEncrypted")
    has_digital_signature: Optional[bool] = Field(alias="hasDigitalSignature")


class ContinueConversationContinueConversationMessageToolCalls(BaseModel):
    id: str
    name: str
    arguments: str


class ContinueConversationContinueConversationFacets(BaseModel):
    type: Optional[FacetValueTypes]
    value: Optional[str]
    range: Optional["ContinueConversationContinueConversationFacetsRange"]
    count: Optional[Any]
    facet: Optional[ContentFacetTypes]
    observable: Optional["ContinueConversationContinueConversationFacetsObservable"]


class ContinueConversationContinueConversationFacetsRange(BaseModel):
    from_: Optional[str] = Field(alias="from")
    to: Optional[str]


class ContinueConversationContinueConversationFacetsObservable(BaseModel):
    type: Optional[ObservableTypes]
    observable: Optional[
        "ContinueConversationContinueConversationFacetsObservableObservable"
    ]


class ContinueConversationContinueConversationFacetsObservableObservable(BaseModel):
    id: str
    name: Optional[str]


class ContinueConversationContinueConversationGraph(BaseModel):
    nodes: Optional[
        List[Optional["ContinueConversationContinueConversationGraphNodes"]]
    ]
    edges: Optional[
        List[Optional["ContinueConversationContinueConversationGraphEdges"]]
    ]


class ContinueConversationContinueConversationGraphNodes(BaseModel):
    id: str
    name: str
    type: EntityTypes
    metadata: Optional[str]


class ContinueConversationContinueConversationGraphEdges(BaseModel):
    from_: str = Field(alias="from")
    to: str
    relation: Optional[str]


class ContinueConversationContinueConversationDetails(BaseModel):
    model_service: Optional[ModelServiceTypes] = Field(alias="modelService")
    model: Optional[str]
    supports_tool_calling: Optional[bool] = Field(alias="supportsToolCalling")
    source_count: Optional[int] = Field(alias="sourceCount")
    observable_count: Optional[int] = Field(alias="observableCount")
    tool_count: Optional[int] = Field(alias="toolCount")
    rendered_source_count: Optional[int] = Field(alias="renderedSourceCount")
    rendered_observable_count: Optional[int] = Field(alias="renderedObservableCount")
    rendered_tool_count: Optional[int] = Field(alias="renderedToolCount")
    ranked_source_count: Optional[int] = Field(alias="rankedSourceCount")
    ranked_observable_count: Optional[int] = Field(alias="rankedObservableCount")
    ranked_tool_count: Optional[int] = Field(alias="rankedToolCount")
    token_limit: Optional[int] = Field(alias="tokenLimit")
    completion_token_limit: Optional[int] = Field(alias="completionTokenLimit")
    sources: Optional[str]
    formatted_sources: Optional[str] = Field(alias="formattedSources")
    formatted_observables: Optional[str] = Field(alias="formattedObservables")
    formatted_instructions: Optional[str] = Field(alias="formattedInstructions")
    formatted_tools: Optional[str] = Field(alias="formattedTools")
    specification: Optional[str]
    messages: Optional[
        List[Optional["ContinueConversationContinueConversationDetailsMessages"]]
    ]


class ContinueConversationContinueConversationDetailsMessages(BaseModel):
    role: ConversationRoleTypes
    author: Optional[str]
    message: Optional[str]
    citations: Optional[
        List[
            Optional["ContinueConversationContinueConversationDetailsMessagesCitations"]
        ]
    ]
    tool_calls: Optional[
        List[
            Optional["ContinueConversationContinueConversationDetailsMessagesToolCalls"]
        ]
    ] = Field(alias="toolCalls")
    tokens: Optional[int]
    throughput: Optional[float]
    ttft: Optional[Any]
    completion_time: Optional[Any] = Field(alias="completionTime")
    timestamp: Optional[Any]
    model_service: Optional[ModelServiceTypes] = Field(alias="modelService")
    model: Optional[str]
    data: Optional[str]
    mime_type: Optional[str] = Field(alias="mimeType")
    tool_call_id: Optional[str] = Field(alias="toolCallId")
    tool_call_response: Optional[str] = Field(alias="toolCallResponse")


class ContinueConversationContinueConversationDetailsMessagesCitations(BaseModel):
    content: Optional[
        "ContinueConversationContinueConversationDetailsMessagesCitationsContent"
    ]
    index: Optional[int]
    text: str
    start_time: Optional[Any] = Field(alias="startTime")
    end_time: Optional[Any] = Field(alias="endTime")
    page_number: Optional[int] = Field(alias="pageNumber")
    frame_number: Optional[int] = Field(alias="frameNumber")


class ContinueConversationContinueConversationDetailsMessagesCitationsContent(
    BaseModel
):
    id: str
    name: str
    state: EntityState
    original_date: Optional[Any] = Field(alias="originalDate")
    identifier: Optional[str]
    uri: Optional[Any]
    type: Optional[ContentTypes]
    file_type: Optional[FileTypes] = Field(alias="fileType")
    mime_type: Optional[str] = Field(alias="mimeType")
    format: Optional[str]
    format_name: Optional[str] = Field(alias="formatName")
    file_extension: Optional[str] = Field(alias="fileExtension")
    file_name: Optional[str] = Field(alias="fileName")
    file_size: Optional[Any] = Field(alias="fileSize")
    master_uri: Optional[Any] = Field(alias="masterUri")
    image_uri: Optional[Any] = Field(alias="imageUri")
    text_uri: Optional[Any] = Field(alias="textUri")
    audio_uri: Optional[Any] = Field(alias="audioUri")
    transcript_uri: Optional[Any] = Field(alias="transcriptUri")
    summary: Optional[str]
    custom_summary: Optional[str] = Field(alias="customSummary")
    keywords: Optional[List[str]]
    bullets: Optional[List[str]]
    headlines: Optional[List[str]]
    posts: Optional[List[str]]
    chapters: Optional[List[str]]
    questions: Optional[List[str]]
    quotes: Optional[List[str]]
    video: Optional[
        "ContinueConversationContinueConversationDetailsMessagesCitationsContentVideo"
    ]
    audio: Optional[
        "ContinueConversationContinueConversationDetailsMessagesCitationsContentAudio"
    ]
    image: Optional[
        "ContinueConversationContinueConversationDetailsMessagesCitationsContentImage"
    ]
    document: Optional[
        "ContinueConversationContinueConversationDetailsMessagesCitationsContentDocument"
    ]


class ContinueConversationContinueConversationDetailsMessagesCitationsContentVideo(
    BaseModel
):
    width: Optional[int]
    height: Optional[int]
    duration: Optional[Any]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    title: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]


class ContinueConversationContinueConversationDetailsMessagesCitationsContentAudio(
    BaseModel
):
    keywords: Optional[List[Optional[str]]]
    author: Optional[str]
    series: Optional[str]
    episode: Optional[str]
    episode_type: Optional[str] = Field(alias="episodeType")
    season: Optional[str]
    publisher: Optional[str]
    copyright: Optional[str]
    genre: Optional[str]
    title: Optional[str]
    description: Optional[str]
    bitrate: Optional[int]
    channels: Optional[int]
    sample_rate: Optional[int] = Field(alias="sampleRate")
    bits_per_sample: Optional[int] = Field(alias="bitsPerSample")
    duration: Optional[Any]


class ContinueConversationContinueConversationDetailsMessagesCitationsContentImage(
    BaseModel
):
    width: Optional[int]
    height: Optional[int]
    resolution_x: Optional[int] = Field(alias="resolutionX")
    resolution_y: Optional[int] = Field(alias="resolutionY")
    bits_per_component: Optional[int] = Field(alias="bitsPerComponent")
    components: Optional[int]
    projection_type: Optional[ImageProjectionTypes] = Field(alias="projectionType")
    orientation: Optional[OrientationTypes]
    description: Optional[str]
    make: Optional[str]
    model: Optional[str]
    software: Optional[str]
    lens: Optional[str]
    focal_length: Optional[float] = Field(alias="focalLength")
    exposure_time: Optional[str] = Field(alias="exposureTime")
    f_number: Optional[str] = Field(alias="fNumber")
    iso: Optional[str]
    heading: Optional[float]
    pitch: Optional[float]


class ContinueConversationContinueConversationDetailsMessagesCitationsContentDocument(
    BaseModel
):
    title: Optional[str]
    subject: Optional[str]
    summary: Optional[str]
    author: Optional[str]
    publisher: Optional[str]
    description: Optional[str]
    keywords: Optional[List[Optional[str]]]
    page_count: Optional[int] = Field(alias="pageCount")
    worksheet_count: Optional[int] = Field(alias="worksheetCount")
    slide_count: Optional[int] = Field(alias="slideCount")
    word_count: Optional[int] = Field(alias="wordCount")
    line_count: Optional[int] = Field(alias="lineCount")
    paragraph_count: Optional[int] = Field(alias="paragraphCount")
    is_encrypted: Optional[bool] = Field(alias="isEncrypted")
    has_digital_signature: Optional[bool] = Field(alias="hasDigitalSignature")


class ContinueConversationContinueConversationDetailsMessagesToolCalls(BaseModel):
    id: str
    name: str
    arguments: str


ContinueConversation.model_rebuild()
ContinueConversationContinueConversation.model_rebuild()
ContinueConversationContinueConversationMessage.model_rebuild()
ContinueConversationContinueConversationMessageCitations.model_rebuild()
ContinueConversationContinueConversationMessageCitationsContent.model_rebuild()
ContinueConversationContinueConversationFacets.model_rebuild()
ContinueConversationContinueConversationFacetsObservable.model_rebuild()
ContinueConversationContinueConversationGraph.model_rebuild()
ContinueConversationContinueConversationDetails.model_rebuild()
ContinueConversationContinueConversationDetailsMessages.model_rebuild()
ContinueConversationContinueConversationDetailsMessagesCitations.model_rebuild()
ContinueConversationContinueConversationDetailsMessagesCitationsContent.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryGoogleCalendars(BaseModel):
    google_calendars: Optional["QueryGoogleCalendarsGoogleCalendars"] = Field(
        alias="googleCalendars"
    )


class QueryGoogleCalendarsGoogleCalendars(BaseModel):
    results: Optional[List[Optional["QueryGoogleCalendarsGoogleCalendarsResults"]]]


class QueryGoogleCalendarsGoogleCalendarsResults(BaseModel):
    calendar_name: Optional[str] = Field(alias="calendarName")
    calendar_id: Optional[str] = Field(alias="calendarId")


QueryGoogleCalendars.model_rebuild()
QueryGoogleCalendarsGoogleCalendars.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class CreateMedicalTest(BaseModel):
    create_medical_test: Optional["CreateMedicalTestCreateMedicalTest"] = Field(
        alias="createMedicalTest"
    )


class CreateMedicalTestCreateMedicalTest(BaseModel):
    id: str
    name: str


CreateMedicalTest.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalStudies(BaseModel):
    count_medical_studies: Optional["CountMedicalStudiesCountMedicalStudies"] = Field(
        alias="countMedicalStudies"
    )


class CountMedicalStudiesCountMedicalStudies(BaseModel):
    count: Optional[Any]


CountMedicalStudies.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteMedicalDrug(BaseModel):
    delete_medical_drug: Optional["DeleteMedicalDrugDeleteMedicalDrug"] = Field(
        alias="deleteMedicalDrug"
    )


class DeleteMedicalDrugDeleteMedicalDrug(BaseModel):
    id: str
    state: EntityState


DeleteMedicalDrug.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import EntityState


class DeleteAllMedicalContraindications(BaseModel):
    delete_all_medical_contraindications: Optional[
        List[
            Optional[
                "DeleteAllMedicalContraindicationsDeleteAllMedicalContraindications"
            ]
        ]
    ] = Field(alias="deleteAllMedicalContraindications")


class DeleteAllMedicalContraindicationsDeleteAllMedicalContraindications(BaseModel):
    id: str
    state: EntityState


DeleteAllMedicalContraindications.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalStudy(BaseModel):
    update_medical_study: Optional["UpdateMedicalStudyUpdateMedicalStudy"] = Field(
        alias="updateMedicalStudy"
    )


class UpdateMedicalStudyUpdateMedicalStudy(BaseModel):
    id: str
    name: str


UpdateMedicalStudy.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpdateMedicalDrug(BaseModel):
    update_medical_drug: Optional["UpdateMedicalDrugUpdateMedicalDrug"] = Field(
        alias="updateMedicalDrug"
    )


class UpdateMedicalDrugUpdateMedicalDrug(BaseModel):
    id: str
    name: str


UpdateMedicalDrug.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountCategories(BaseModel):
    count_categories: Optional["CountCategoriesCountCategories"] = Field(
        alias="countCategories"
    )


class CountCategoriesCountCategories(BaseModel):
    count: Optional[Any]


CountCategories.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, Optional

from pydantic import Field

from .base_model import BaseModel


class CountMedicalConditions(BaseModel):
    count_medical_conditions: Optional[
        "CountMedicalConditionsCountMedicalConditions"
    ] = Field(alias="countMedicalConditions")


class CountMedicalConditionsCountMedicalConditions(BaseModel):
    count: Optional[Any]


CountMedicalConditions.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel


class GetMedicalProcedure(BaseModel):
    medical_procedure: Optional["GetMedicalProcedureMedicalProcedure"] = Field(
        alias="medicalProcedure"
    )


class GetMedicalProcedureMedicalProcedure(BaseModel):
    id: str
    name: str
    alternate_names: Optional[List[Optional[str]]] = Field(alias="alternateNames")
    creation_date: Any = Field(alias="creationDate")
    uri: Optional[Any]
    description: Optional[str]
    identifier: Optional[str]
    thing: Optional[str]
    relevance: Optional[float]


GetMedicalProcedure.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class UpsertCategory(BaseModel):
    upsert_category: Optional["UpsertCategoryUpsertCategory"] = Field(
        alias="upsertCategory"
    )


class UpsertCategoryUpsertCategory(BaseModel):
    id: str
    name: str


UpsertCategory.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Any, List, Optional

from pydantic import Field

from .base_model import BaseModel
from .enums import (
    AssemblyAIModels,
    AzureDocumentIntelligenceModels,
    AzureDocumentIntelligenceVersions,
    ContentClassificationServiceTypes,
    ContentIndexingServiceTypes,
    ContentTypes,
    DeepgramModels,
    EntityEnrichmentServiceTypes,
    EntityExtractionServiceTypes,
    EntityState,
    FilePreparationServiceTypes,
    FileTypes,
    IntegrationServiceTypes,
    LinkTypes,
    ObservableTypes,
    ReductoEnrichmentModes,
    ReductoExtractionModes,
    ReductoOcrModes,
    ReductoOcrSystems,
    RegexSourceTypes,
    StoragePolicyTypes,
    SummarizationTypes,
)


class UpsertWorkflow(BaseModel):
    upsert_workflow: Optional["UpsertWorkflowUpsertWorkflow"] = Field(
        alias="upsertWorkflow"
    )


class UpsertWorkflowUpsertWorkflow(BaseModel):
    id: str
    name: str
    state: EntityState
    ingestion: Optional["UpsertWorkflowUpsertWorkflowIngestion"]
    indexing: Optional["UpsertWorkflowUpsertWorkflowIndexing"]
    preparation: Optional["UpsertWorkflowUpsertWorkflowPreparation"]
    extraction: Optional["UpsertWorkflowUpsertWorkflowExtraction"]
    classification: Optional["UpsertWorkflowUpsertWorkflowClassification"]
    enrichment: Optional["UpsertWorkflowUpsertWorkflowEnrichment"]
    storage: Optional["UpsertWorkflowUpsertWorkflowStorage"]
    actions: Optional[List[Optional["UpsertWorkflowUpsertWorkflowActions"]]]


class UpsertWorkflowUpsertWorkflowIngestion(BaseModel):
    if_: Optional["UpsertWorkflowUpsertWorkflowIngestionIf"] = Field(alias="if")
    collections: Optional[
        List[Optional["UpsertWorkflowUpsertWorkflowIngestionCollections"]]
    ]
    observations: Optional[
        List[Optional["UpsertWorkflowUpsertWorkflowIngestionObservations"]]
    ]
    enable_email_collections: Optional[bool] = Field(alias="enableEmailCollections")


class UpsertWorkflowUpsertWorkflowIngestionIf(BaseModel):
    types: Optional[List[ContentTypes]]
    file_types: Optional[List[FileTypes]] = Field(alias="fileTypes")
    formats: Optional[List[Optional[str]]]
    file_extensions: Optional[List[str]] = Field(alias="fileExtensions")
    allowed_paths: Optional[List[str]] = Field(alias="allowedPaths")
    excluded_paths: Optional[List[str]] = Field(alias="excludedPaths")


class UpsertWorkflowUpsertWorkflowIngestionCollections(BaseModel):
    id: str


class UpsertWorkflowUpsertWorkflowIngestionObservations(BaseModel):
    type: ObservableTypes
    observable: "UpsertWorkflowUpsertWorkflowIngestionObservationsObservable"


class UpsertWorkflowUpsertWorkflowIngestionObservationsObservable(BaseModel):
    id: str
    name: Optional[str]


class UpsertWorkflowUpsertWorkflowIndexing(BaseModel):
    jobs: Optional[List[Optional["UpsertWorkflowUpsertWorkflowIndexingJobs"]]]


class UpsertWorkflowUpsertWorkflowIndexingJobs(BaseModel):
    connector: Optional["UpsertWorkflowUpsertWorkflowIndexingJobsConnector"]


class UpsertWorkflowUpsertWorkflowIndexingJobsConnector(BaseModel):
    type: Optional[ContentIndexingServiceTypes]
    content_type: Optional[ContentTypes] = Field(alias="contentType")
    file_type: Optional[FileTypes] = Field(alias="fileType")


class UpsertWorkflowUpsertWorkflowPreparation(BaseModel):
    enable_unblocked_capture: Optional[bool] = Field(alias="enableUnblockedCapture")
    disable_smart_capture: Optional[bool] = Field(alias="disableSmartCapture")
    summarizations: Optional[
        List[Optional["UpsertWorkflowUpsertWorkflowPreparationSummarizations"]]
    ]
    jobs: Optional[List[Optional["UpsertWorkflowUpsertWorkflowPreparationJobs"]]]


class UpsertWorkflowUpsertWorkflowPreparationSummarizations(BaseModel):
    type: SummarizationTypes
    specification: Optional[
        "UpsertWorkflowUpsertWorkflowPreparationSummarizationsSpecification"
    ]
    tokens: Optional[int]
    items: Optional[int]
    prompt: Optional[str]


class UpsertWorkflowUpsertWorkflowPreparationSummarizationsSpecification(BaseModel):
    id: str


class UpsertWorkflowUpsertWorkflowPreparationJobs(BaseModel):
    connector: Optional["UpsertWorkflowUpsertWorkflowPreparationJobsConnector"]


class UpsertWorkflowUpsertWorkflowPreparationJobsConnector(BaseModel):
    type: FilePreparationServiceTypes
    file_types: Optional[List[FileTypes]] = Field(alias="fileTypes")
    azure_document: Optional[
        "UpsertWorkflowUpsertWorkflowPreparationJobsConnectorAzureDocument"
    ] = Field(alias="azureDocument")
    deepgram: Optional["UpsertWorkflowUpsertWorkflowPreparationJobsConnectorDeepgram"]
    assembly_ai: Optional[
        "UpsertWorkflowUpsertWorkflowPreparationJobsConnectorAssemblyAi"
    ] = Field(alias="assemblyAI")
    page: Optional["UpsertWorkflowUpsertWorkflowPreparationJobsConnectorPage"]
    document: Optional["UpsertWorkflowUpsertWorkflowPreparationJobsConnectorDocument"]
    email: Optional["UpsertWorkflowUpsertWorkflowPreparationJobsConnectorEmail"]
    model_document: Optional[
        "UpsertWorkflowUpsertWorkflowPreparationJobsConnectorModelDocument"
    ] = Field(alias="modelDocument")
    reducto: Optional["UpsertWorkflowUpsertWorkflowPreparationJobsConnectorReducto"]
    mistral: Optional["UpsertWorkflowUpsertWorkflowPreparationJobsConnectorMistral"]


class UpsertWorkflowUpsertWorkflowPreparationJobsConnectorAzureDocument(BaseModel):
    version: Optional[AzureDocumentIntelligenceVersions]
    model: Optional[AzureDocumentIntelligenceModels]
    endpoint: Optional[Any]
    key: Optional[str]


class UpsertWorkflowUpsertWorkflowPreparationJobsConnectorDeepgram(BaseModel):
    model: Optional[DeepgramModels]
    key: Optional[str]
    enable_redaction: Optional[bool] = Field(alias="enableRedaction")
    enable_speaker_diarization: Optional[bool] = Field(alias="enableSpeakerDiarization")
    detect_language: Optional[bool] = Field(alias="detectLanguage")
    language: Optional[str]


class UpsertWorkflowUpsertWorkflowPreparationJobsConnectorAssemblyAi(BaseModel):
    model: Optional[AssemblyAIModels]
    key: Optional[str]
    enable_redaction: Optional[bool] = Field(alias="enableRedaction")
    enable_speaker_diarization: Optional[bool] = Field(alias="enableSpeakerDiarization")
    detect_language: Optional[bool] = Field(alias="detectLanguage")
    language: Optional[str]


class UpsertWorkflowUpsertWorkflowPreparationJobsConnectorPage(BaseModel):
    enable_screenshot: Optional[bool] = Field(alias="enableScreenshot")


class UpsertWorkflowUpsertWorkflowPreparationJobsConnectorDocument(BaseModel):
    include_images: Optional[bool] = Field(alias="includeImages")


class UpsertWorkflowUpsertWorkflowPreparationJobsConnectorEmail(BaseModel):
    include_attachments: Optional[bool] = Field(alias="includeAttachments")


class UpsertWorkflowUpsertWorkflowPreparationJobsConnectorModelDocument(BaseModel):
    specification: Optional[
        "UpsertWorkflowUpsertWorkflowPreparationJobsConnectorModelDocumentSpecification"
    ]


class UpsertWorkflowUpsertWorkflowPreparationJobsConnectorModelDocumentSpecification(
    BaseModel
):
    id: str


class UpsertWorkflowUpsertWorkflowPreparationJobsConnectorReducto(BaseModel):
    ocr_mode: Optional[ReductoOcrModes] = Field(alias="ocrMode")
    ocr_system: Optional[ReductoOcrSystems] = Field(alias="ocrSystem")
    extraction_mode: Optional[ReductoExtractionModes] = Field(alias="extractionMode")
    enable_enrichment: Optional[bool] = Field(alias="enableEnrichment")
    enrichment_mode: Optional[ReductoEnrichmentModes] = Field(alias="enrichmentMode")
    key: Optional[str]


class UpsertWorkflowUpsertWorkflowPreparationJobsConnectorMistral(BaseModel):
    key: Optional[str]


class UpsertWorkflowUpsertWorkflowExtraction(BaseModel):
    jobs: Optional[List[Optional["UpsertWorkflowUpsertWorkflowExtractionJobs"]]]


class UpsertWorkflowUpsertWorkflowExtractionJobs(BaseModel):
    connector: Optional["UpsertWorkflowUpsertWorkflowExtractionJobsConnector"]


class UpsertWorkflowUpsertWorkflowExtractionJobsConnector(BaseModel):
    type: EntityExtractionServiceTypes
    content_types: Optional[List[ContentTypes]] = Field(alias="contentTypes")
    file_types: Optional[List[FileTypes]] = Field(alias="fileTypes")
    extracted_types: Optional[List[ObservableTypes]] = Field(alias="extractedTypes")
    extracted_count: Optional[int] = Field(alias="extractedCount")
    azure_text: Optional[
        "UpsertWorkflowUpsertWorkflowExtractionJobsConnectorAzureText"
    ] = Field(alias="azureText")
    azure_image: Optional[
        "UpsertWorkflowUpsertWorkflowExtractionJobsConnectorAzureImage"
    ] = Field(alias="azureImage")
    model_image: Optional[
        "UpsertWorkflowUpsertWorkflowExtractionJobsConnectorModelImage"
    ] = Field(alias="modelImage")
    model_text: Optional[
        "UpsertWorkflowUpsertWorkflowExtractionJobsConnectorModelText"
    ] = Field(alias="modelText")


class UpsertWorkflowUpsertWorkflowExtractionJobsConnectorAzureText(BaseModel):
    confidence_threshold: Optional[float] = Field(alias="confidenceThreshold")
    enable_pii: Optional[bool] = Field(alias="enablePII")


class UpsertWorkflowUpsertWorkflowExtractionJobsConnectorAzureImage(BaseModel):
    confidence_threshold: Optional[float] = Field(alias="confidenceThreshold")


class UpsertWorkflowUpsertWorkflowExtractionJobsConnectorModelImage(BaseModel):
    specification: Optional[
        "UpsertWorkflowUpsertWorkflowExtractionJobsConnectorModelImageSpecification"
    ]


class UpsertWorkflowUpsertWorkflowExtractionJobsConnectorModelImageSpecification(
    BaseModel
):
    id: str


class UpsertWorkflowUpsertWorkflowExtractionJobsConnectorModelText(BaseModel):
    specification: Optional[
        "UpsertWorkflowUpsertWorkflowExtractionJobsConnectorModelTextSpecification"
    ]


class UpsertWorkflowUpsertWorkflowExtractionJobsConnectorModelTextSpecification(
    BaseModel
):
    id: str


class UpsertWorkflowUpsertWorkflowClassification(BaseModel):
    jobs: Optional[List[Optional["UpsertWorkflowUpsertWorkflowClassificationJobs"]]]


class UpsertWorkflowUpsertWorkflowClassificationJobs(BaseModel):
    connector: Optional["UpsertWorkflowUpsertWorkflowClassificationJobsConnector"]


class UpsertWorkflowUpsertWorkflowClassificationJobsConnector(BaseModel):
    type: ContentClassificationServiceTypes
    content_type: Optional[ContentTypes] = Field(alias="contentType")
    file_type: Optional[FileTypes] = Field(alias="fileType")
    model: Optional["UpsertWorkflowUpsertWorkflowClassificationJobsConnectorModel"]
    regex: Optional["UpsertWorkflowUpsertWorkflowClassificationJobsConnectorRegex"]


class UpsertWorkflowUpsertWorkflowClassificationJobsConnectorModel(BaseModel):
    specification: Optional[
        "UpsertWorkflowUpsertWorkflowClassificationJobsConnectorModelSpecification"
    ]
    rules: Optional[
        List[
            Optional[
                "UpsertWorkflowUpsertWorkflowClassificationJobsConnectorModelRules"
            ]
        ]
    ]


class UpsertWorkflowUpsertWorkflowClassificationJobsConnectorModelSpecification(
    BaseModel
):
    id: str


class UpsertWorkflowUpsertWorkflowClassificationJobsConnectorModelRules(BaseModel):
    then: Optional[str]
    if_: Optional[str] = Field(alias="if")


class UpsertWorkflowUpsertWorkflowClassificationJobsConnectorRegex(BaseModel):
    rules: Optional[
        List[
            Optional[
                "UpsertWorkflowUpsertWorkflowClassificationJobsConnectorRegexRules"
            ]
        ]
    ]


class UpsertWorkflowUpsertWorkflowClassificationJobsConnectorRegexRules(BaseModel):
    then: Optional[str]
    type: Optional[RegexSourceTypes]
    path: Optional[str]
    matches: Optional[str]


class UpsertWorkflowUpsertWorkflowEnrichment(BaseModel):
    link: Optional["UpsertWorkflowUpsertWorkflowEnrichmentLink"]
    jobs: Optional[List[Optional["UpsertWorkflowUpsertWorkflowEnrichmentJobs"]]]


class UpsertWorkflowUpsertWorkflowEnrichmentLink(BaseModel):
    enable_crawling: Optional[bool] = Field(alias="enableCrawling")
    allowed_domains: Optional[List[str]] = Field(alias="allowedDomains")
    excluded_domains: Optional[List[str]] = Field(alias="excludedDomains")
    allowed_paths: Optional[List[str]] = Field(alias="allowedPaths")
    excluded_paths: Optional[List[str]] = Field(alias="excludedPaths")
    allowed_links: Optional[List[LinkTypes]] = Field(alias="allowedLinks")
    excluded_links: Optional[List[LinkTypes]] = Field(alias="excludedLinks")
    allowed_files: Optional[List[FileTypes]] = Field(alias="allowedFiles")
    excluded_files: Optional[List[FileTypes]] = Field(alias="excludedFiles")
    allow_content_domain: Optional[bool] = Field(alias="allowContentDomain")
    maximum_links: Optional[int] = Field(alias="maximumLinks")


class UpsertWorkflowUpsertWorkflowEnrichmentJobs(BaseModel):
    connector: Optional["UpsertWorkflowUpsertWorkflowEnrichmentJobsConnector"]


class UpsertWorkflowUpsertWorkflowEnrichmentJobsConnector(BaseModel):
    type: Optional[EntityEnrichmentServiceTypes]
    enriched_types: Optional[List[Optional[ObservableTypes]]] = Field(
        alias="enrichedTypes"
    )
    fhir: Optional["UpsertWorkflowUpsertWorkflowEnrichmentJobsConnectorFhir"]
    diffbot: Optional["UpsertWorkflowUpsertWorkflowEnrichmentJobsConnectorDiffbot"]


class UpsertWorkflowUpsertWorkflowEnrichmentJobsConnectorFhir(BaseModel):
    endpoint: Optional[Any]


class UpsertWorkflowUpsertWorkflowEnrichmentJobsConnectorDiffbot(BaseModel):
    key: Optional[Any]


class UpsertWorkflowUpsertWorkflowStorage(BaseModel):
    policy: Optional["UpsertWorkflowUpsertWorkflowStoragePolicy"]


class UpsertWorkflowUpsertWorkflowStoragePolicy(BaseModel):
    type: Optional[StoragePolicyTypes]
    allow_duplicates: Optional[bool] = Field(alias="allowDuplicates")


class UpsertWorkflowUpsertWorkflowActions(BaseModel):
    connector: Optional["UpsertWorkflowUpsertWorkflowActionsConnector"]


class UpsertWorkflowUpsertWorkflowActionsConnector(BaseModel):
    type: IntegrationServiceTypes
    uri: Optional[str]
    slack: Optional["UpsertWorkflowUpsertWorkflowActionsConnectorSlack"]
    email: Optional["UpsertWorkflowUpsertWorkflowActionsConnectorEmail"]
    twitter: Optional["UpsertWorkflowUpsertWorkflowActionsConnectorTwitter"]


class UpsertWorkflowUpsertWorkflowActionsConnectorSlack(BaseModel):
    token: str
    channel: str


class UpsertWorkflowUpsertWorkflowActionsConnectorEmail(BaseModel):
    from_: str = Field(alias="from")
    subject: str
    to: List[str]


class UpsertWorkflowUpsertWorkflowActionsConnectorTwitter(BaseModel):
    consumer_key: str = Field(alias="consumerKey")
    consumer_secret: str = Field(alias="consumerSecret")
    access_token_key: str = Field(alias="accessTokenKey")
    access_token_secret: str = Field(alias="accessTokenSecret")


UpsertWorkflow.model_rebuild()
UpsertWorkflowUpsertWorkflow.model_rebuild()
UpsertWorkflowUpsertWorkflowIngestion.model_rebuild()
UpsertWorkflowUpsertWorkflowIngestionObservations.model_rebuild()
UpsertWorkflowUpsertWorkflowIndexing.model_rebuild()
UpsertWorkflowUpsertWorkflowIndexingJobs.model_rebuild()
UpsertWorkflowUpsertWorkflowPreparation.model_rebuild()
UpsertWorkflowUpsertWorkflowPreparationSummarizations.model_rebuild()
UpsertWorkflowUpsertWorkflowPreparationJobs.model_rebuild()
UpsertWorkflowUpsertWorkflowPreparationJobsConnector.model_rebuild()
UpsertWorkflowUpsertWorkflowPreparationJobsConnectorModelDocument.model_rebuild()
UpsertWorkflowUpsertWorkflowExtraction.model_rebuild()
UpsertWorkflowUpsertWorkflowExtractionJobs.model_rebuild()
UpsertWorkflowUpsertWorkflowExtractionJobsConnector.model_rebuild()
UpsertWorkflowUpsertWorkflowExtractionJobsConnectorModelImage.model_rebuild()
UpsertWorkflowUpsertWorkflowExtractionJobsConnectorModelText.model_rebuild()
UpsertWorkflowUpsertWorkflowClassification.model_rebuild()
UpsertWorkflowUpsertWorkflowClassificationJobs.model_rebuild()
UpsertWorkflowUpsertWorkflowClassificationJobsConnector.model_rebuild()
UpsertWorkflowUpsertWorkflowClassificationJobsConnectorModel.model_rebuild()
UpsertWorkflowUpsertWorkflowClassificationJobsConnectorRegex.model_rebuild()
UpsertWorkflowUpsertWorkflowEnrichment.model_rebuild()
UpsertWorkflowUpsertWorkflowEnrichmentJobs.model_rebuild()
UpsertWorkflowUpsertWorkflowEnrichmentJobsConnector.model_rebuild()
UpsertWorkflowUpsertWorkflowStorage.model_rebuild()
UpsertWorkflowUpsertWorkflowActions.model_rebuild()
UpsertWorkflowUpsertWorkflowActionsConnector.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import Optional

from pydantic import Field

from .base_model import BaseModel


class SpecificationExists(BaseModel):
    specification_exists: Optional["SpecificationExistsSpecificationExists"] = Field(
        alias="specificationExists"
    )


class SpecificationExistsSpecificationExists(BaseModel):
    result: Optional[bool]


SpecificationExists.model_rebuild()



# Generated by ariadne-codegen
# Source: ./documents

from typing import List, Optional

from pydantic import Field

from .base_model import BaseModel


class QueryDropboxFolders(BaseModel):
    dropbox_folders: Optional["QueryDropboxFoldersDropboxFolders"] = Field(
        alias="dropboxFolders"
    )


class QueryDropboxFoldersDropboxFolders(BaseModel):
    results: Optional[List[Optional["QueryDropboxFoldersDropboxFoldersResults"]]]


class QueryDropboxFoldersDropboxFoldersResults(BaseModel):
    folder_name: Optional[str] = Field(alias="folderName")
    folder_id: Optional[str] = Field(alias="folderId")


QueryDropboxFolders.model_rebuild()
QueryDropboxFoldersDropboxFolders.model_rebuild()
